==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/openShop/GetDetailByApplyIdResponse.java <==
package eleme.openapi.sdk.api.entity.openShop;

import java.util.*;

public class GetDetailByApplyIdResponse{

    /**
     * 开店申请id
     */
    private Long applyId;
    public Long getApplyId() {
        return applyId;
    }
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    
    /**
     * 店铺名称
     */
    private String storeName;
    public String getStoreName() {
        return storeName;
    }
    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    
    /**
     * 商户id
     */
    private Long merchantId;
    public Long getMerchantId() {
        return merchantId;
    }
    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
    
    /**
     * 地址信息
     */
    private AddressInfo addressInfo;
    public AddressInfo getAddressInfo() {
        return addressInfo;
    }
    public void setAddressInfo(AddressInfo addressInfo) {
        this.addressInfo = addressInfo;
    }
    
    /**
     * 联系人信息
     */
    private ContactInfo contactInfo;
    public ContactInfo getContactInfo() {
        return contactInfo;
    }
    public void setContactInfo(ContactInfo contactInfo) {
        this.contactInfo = contactInfo;
    }
    
    /**
     * 执照信息
     */
    private List<ShopCertificationInfo> certificationInfos;
    public List<ShopCertificationInfo> getCertificationInfos() {
        return certificationInfos;
    }
    public void setCertificationInfos(List<ShopCertificationInfo> certificationInfos) {
        this.certificationInfos = certificationInfos;
    }
    
    /**
     * 品类信息
     */
    private List<CategoryInfo> categories;
    public List<CategoryInfo> getCategories() {
        return categories;
    }
    public void setCategories(List<CategoryInfo> categories) {
        this.categories = categories;
    }
    
    /**
     * 图片信息
     */
    private List<ApplyImageInfo> images;
    public List<ApplyImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ApplyImageInfo> images) {
        this.images = images;
    }
    
    /**
     * 开店审核状态
     */
    private Integer status;
    public Integer getStatus() {
        return status;
    }
    public void setStatus(Integer status) {
        this.status = status;
    }
    
    /**
     * 驳回原因
     */
    private List<RefuseReasonVO> refuseReasons;
    public List<RefuseReasonVO> getRefuseReasons() {
        return refuseReasons;
    }
    public void setRefuseReasons(List<RefuseReasonVO> refuseReasons) {
        this.refuseReasons = refuseReasons;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/openShop/GetDetailByApplyIdResponse.java <==
package eleme.openapi.sdk.api.entity.openShop;

import eleme.openapi.sdk.api.enumeration.openShop.*;
import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class GetDetailByApplyIdResponse{

    /**
     * 开店申请id
     */
    private Long applyId;
    public Long getApplyId() {
        return applyId;
    }
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    
    /**
     * 店铺名称
     */
    private String storeName;
    public String getStoreName() {
        return storeName;
    }
    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    
    /**
     * 商户id
     */
    private Long merchantId;
    public Long getMerchantId() {
        return merchantId;
    }
    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
    
    /**
     * 地址信息
     */
    private AddressInfo addressInfo;
    public AddressInfo getAddressInfo() {
        return addressInfo;
    }
    public void setAddressInfo(AddressInfo addressInfo) {
        this.addressInfo = addressInfo;
    }
    
    /**
     * 联系人信息
     */
    private ContactInfo contactInfo;
    public ContactInfo getContactInfo() {
        return contactInfo;
    }
    public void setContactInfo(ContactInfo contactInfo) {
        this.contactInfo = contactInfo;
    }
    
    /**
     * 执照信息
     */
    private List<ShopCertificationInfo> certificationInfos;
    public List<ShopCertificationInfo> getCertificationInfos() {
        return certificationInfos;
    }
    public void setCertificationInfos(List<ShopCertificationInfo> certificationInfos) {
        this.certificationInfos = certificationInfos;
    }
    
    /**
     * 品类信息
     */
    private List<CategoryInfo> categories;
    public List<CategoryInfo> getCategories() {
        return categories;
    }
    public void setCategories(List<CategoryInfo> categories) {
        this.categories = categories;
    }
    
    /**
     * 图片信息
     */
    private List<ApplyImageInfo> images;
    public List<ApplyImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ApplyImageInfo> images) {
        this.images = images;
    }
    
    /**
     * 开店审核状态
     */
    private Integer status;
    public Integer getStatus() {
        return status;
    }
    public void setStatus(Integer status) {
        this.status = status;
    }
    
    /**
     * 驳回原因
     */
    private List<RefuseReasonVO> refuseReasons;
    public List<RefuseReasonVO> getRefuseReasons() {
        return refuseReasons;
    }
    public void setRefuseReasons(List<RefuseReasonVO> refuseReasons) {
        this.refuseReasons = refuseReasons;
    }
    
}
